from distutils.core import setup
setup(
  name = 'justToTestPYPI',
  packages = ['justToTestPYPI'],
  version = '0.1',
  license='MIT',
  description = 'just to test PYPI',
  author = 'fatfishcc',
  author_email = 'fatfishcc@pampas.io',
  url = 'https://github.com/user/reponame',
  download_url = 'https://github.com/fatfishcc/justToTestPYPI/archive/v0.1.tar.gz',
  keywords = ['TEST'],
  install_requires=[ 
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.8',
  ],
)
